@@ -4,7 +4,6 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 // Own
 #include "collectionwidget.h"
 
@@ -14,61 +13,54 @@
 #include <KLocalizedString>
 
 // Qt
+#include <QColor>
+#include <QGraphicsDropShadowEffect>
+#include <QLabel>
 #include <QPainter>
 #include <QPen>
-#include <QColor>
 #include <QPushButton>
-#include <QGraphicsDropShadowEffect>
 #include <QVBoxLayout>
-#include <QLabel>
 
 // Parley
 #include "utils.h"
 
-
 // Size constants for the collection widgets
-int COLLWIDTH   = 155; // Width in pixels of a collection widget
-//int COLLHEIGHT1 = 250; // Height in pixels of a collection widget not yet fully learned
+int COLLWIDTH = 155; // Width in pixels of a collection widget
+// int COLLHEIGHT1 = 250; // Height in pixels of a collection widget not yet fully learned
 int COLLHEIGHT1 = 175; // Height in pixels of a collection widget not yet fully learned
 int COLLHEIGHT2 = 125; // Height in pixels of a collection widget fully learned
 
-
 // ================================================================
 //                        private classes
 
-
-
 // The RemoveButton is a button that the user can press in a collection to
 // remove the collection from the word bank.
 
-
 class RemoveButton : public QPushButton
 {
 public:
     RemoveButton(QWidget *parent = 0);
 
 protected:
-    void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent *) override;
 };
 
-
 RemoveButton::RemoveButton(QWidget *parent)
     : QPushButton(parent)
 {
 }
 
-
-void RemoveButton::paintEvent(QPaintEvent*)
+void RemoveButton::paintEvent(QPaintEvent *)
 {
     QPainter painter(this);
-    QPen pen(QColor(255,255,255));
+    QPen pen(QColor(255, 255, 255));
     painter.setPen(pen);
     painter.setRenderHint(QPainter::Antialiasing, true);
-    QBrush brush(QColor(49,54,59));
+    QBrush brush(QColor(49, 54, 59));
     painter.setBrush(brush);
 
     painter.drawEllipse(QRectF(1.0, 1.0, height() - 1.0, height() - 1.0));
-    painter.setFont( QFont( QStringLiteral("Helvetica"), 7, QFont::Bold, false));
+    painter.setFont(QFont(QStringLiteral("Helvetica"), 7, QFont::Bold, false));
     painter.drawText(2, 1, height() - 2, height() - 1, Qt::AlignCenter, QStringLiteral("x"));
 }
 
@@ -84,7 +76,6 @@ CollectionWidget::~CollectionWidget()
 {
 }
 
-
 Collection *CollectionWidget::collection() const
 {
     return m_collection;
@@ -97,27 +88,24 @@ void CollectionWidget::setCollection(Collection *collection)
 
 void CollectionWidget::updateDue()
 {
-    WordCount  due;
+    WordCount due;
     m_collection->numDueWords(due);
     m_barWidget->setDue(due);
 
     if (due.totalWords == 0 /* && due->percentageCompleted < 100*/) {
         m_practiceButton->setText(i18n("Practice Anyway"));
-    }
-    else {
+    } else {
         m_practiceButton->setText(i18n("Practice"));
     }
 }
 
-
 // ----------------------------------------------------------------
 //                         private classes
 
-
 void CollectionWidget::setupWidget(WordCount *dueWords)
 {
     // Set a nice shadow effect.
-    QGraphicsDropShadowEffect* effect = new QGraphicsDropShadowEffect();
+    QGraphicsDropShadowEffect *effect = new QGraphicsDropShadowEffect();
     effect->setBlurRadius(50);
     this->setGraphicsEffect(effect);
     QPalette palette = this->palette();
@@ -128,7 +116,7 @@ void CollectionWidget::setupWidget(WordCount *dueWords)
     // Fill in the contents of the widget.
 
     // mainLayout is the main vertical layout for one collection widget.
-    QVBoxLayout* mainLayout = new QVBoxLayout();
+    QVBoxLayout *mainLayout = new QVBoxLayout();
     mainLayout->setAlignment(Qt::AlignCenter);
     this->setLayout(mainLayout);
 
@@ -149,7 +137,7 @@ void CollectionWidget::setupWidget(WordCount *dueWords)
     pixmap.fill(Qt::lightGray);
     m_thumbnail->setPixmap(pixmap);
 
-    int  percentageCompleted = dueWords->percentageCompleted();
+    int percentageCompleted = dueWords->percentageCompleted();
     if (percentageCompleted != 100) {
         mainLayout->addWidget(m_thumbnail);
     }
@@ -158,9 +146,8 @@ void CollectionWidget::setupWidget(WordCount *dueWords)
     m_barWidget->setFixedSize(COLLWIDTH - 10, 45);
     mainLayout->addWidget(m_barWidget);
     m_practiceButton = new QPushButton(this);
-    QString buttonStyleSheet = "QPushButton { border: none; margin: 0px; padding: 0px; color: " +
-            palette.color(QPalette::Active, QPalette::ButtonText).name()+ "; background-color: " +
-            palette.color(QPalette::Active, QPalette::Button).name() + "; border-radius: 3px;}";
+    QString buttonStyleSheet = "QPushButton { border: none; margin: 0px; padding: 0px; color: " + palette.color(QPalette::Active, QPalette::ButtonText).name()
+        + "; background-color: " + palette.color(QPalette::Active, QPalette::Button).name() + "; border-radius: 3px;}";
     m_practiceButton->setStyleSheet(buttonStyleSheet);
 
     // buttonLayout is the horizontal layout for the bottom line in the
@@ -179,7 +166,6 @@ void CollectionWidget::setupWidget(WordCount *dueWords)
     connect(m_removeButton, &RemoveButton::clicked, this, &CollectionWidget::removeButtonClicked);
 }
 
-
 void CollectionWidget::fillWidget()
 {
     m_titleLabel->setText(m_collection->eduVocDocument()->title());
